/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.access;


import net.sf.sfac.gui.editor.ModelAccess;


/**
 * Basic implementation of ModelAccess where the editedObject and the modelObject are the same. <br>
 * It means that the ObjectEditor edit directly the object passed to it and not a single field of this object. This is usually
 * the case for the root editor of an editor composite.
 * 
 * @author Olivier Berlanger
 */
public class BasicModelAccess implements ModelAccess {


    private Class<?> editedObjectClass = Object.class;


    public BasicModelAccess(Class<?> referenceClass) {
        editedObjectClass = referenceClass;
    }


    @Override
    public String toString() {
        return getClass().getSimpleName() + "[edited & model=" + editedObjectClass.getSimpleName() + "]";
    }


    public Object getModelValue(Object editedObject) {
        return editedObject;
    }


    public void setModelValue(Object newModelValue, Object editedObject) {
        if (newModelValue != editedObject) throw new IllegalArgumentException("Cannot change model value in " + this);
    }


    public Class<?> getEditedObjectClass() {
        return editedObjectClass;
    }


    public Class<?> getModelClass() {
        // Rem: as this model access has no path, the edited object is the same as the model object.
        return editedObjectClass;
    }


    /**
     * As the model is not directly updated by this ModelAccess, always return true.
     */
    public boolean canUpdateModel() {
        return true;
    }


    public String getFieldPath() {
        return null;
    }


}
