/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.access;


import net.sf.sfac.gui.editor.ModelAccess;
import net.sf.sfac.utils.Comparison;


/**
 * Class allowing to chain model access. <br>
 * You can combine some of them to make the model value retrieved by calling a sequence of getters (like "dossier.person.name").
 * 
 * @author Olivier Berlanger
 */
public abstract class ChainableModelAccess implements ModelAccess {


    private ModelAccess parent;


    public ModelAccess getParent() {
        return parent;
    }


    public void setParent(ModelAccess newParent) {
        parent = newParent;
    }


    public Object getModelValue(Object editedObject) {
        return (parent == null) ? editedObject : parent.getModelValue(editedObject);
    }


    public Class<?> getEditedObjectClass() {
        return (parent == null) ? getThisEditedObjectClass() : parent.getEditedObjectClass();
    }


    public String getFieldPath() {
        String thisFieldPath = getThisFieldPath();
        if (parent == null) return thisFieldPath;
        if (Comparison.isEmpty(thisFieldPath)) return parent.getFieldPath();
        return parent.getFieldPath() + "." + thisFieldPath;
    }


    public abstract Class<?> getThisEditedObjectClass();


    public abstract String getThisFieldPath();


    @Override
    public String toString() {
        Class<?> modelClass = getModelClass();
        String modelClassName = (modelClass == null) ? "?" : modelClass.getSimpleName();
        return getClass().getSimpleName() + "[path=" + getFieldPath() + ", edited=" + getEditedObjectClass().getSimpleName()
                + " --> model=" + modelClassName + "]";
    }

}
