/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.access;


import java.util.Map;


/**
 * Implementation of the ModelAccess interface where the model value is contained in a Map. <br>
 * The model value is accessed get/put methods of the Map.
 * 
 * @author Olivier Berlanger
 */
public class MapModelAccess extends ChainableModelAccess {


    private String key;
    private Class<?> modelClass;


    public MapModelAccess(String fieldName) {
        this(fieldName, Object.class);
    }


    public MapModelAccess(String fieldName, Class<?> mapValueClass) {
        key = fieldName;
        modelClass = mapValueClass;
    }


    @Override
    @SuppressWarnings("unchecked")
    public Object getModelValue(Object baseObject) {
        Object editedObject = super.getModelValue(baseObject);
        if (editedObject == null) return null;
        return ((Map<String, Object>) editedObject).get(key);
    }


    @SuppressWarnings("unchecked")
    public void setModelValue(Object newModelValue, Object baseObject) {
        Object editedObject = super.getModelValue(baseObject);
        if (editedObject == null) throw new NullPointerException("Unable to set value on null object");
        ((Map<String, Object>) editedObject).put(key, newModelValue);
    }


    public boolean canUpdateModel() {
        return true;
    }


    @Override
    public Class<?> getThisEditedObjectClass() {
        return Map.class;
    }


    public Class<?> getModelClass() {
        return modelClass;
    }


    @Override
    public String getThisFieldPath() {
        return key;
    }


}
