/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.cmp;


import java.awt.GridBagConstraints;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JCheckBox;
import javax.swing.JComponent;


/**
 * Editor used to edit a Boolean value. <br>
 * The Boolean can be contained in a Map (the key is provided) or as attribute of a class (Class and attribute name are provided
 * to access it trough reflexion).
 * 
 * @author Olivier Berlanger
 * 
 */
public class BooleanEditor extends SimpleObjectEditor {


    private JCheckBox checkBox;


    public BooleanEditor() {
        setProperty("fill", Integer.valueOf(GridBagConstraints.NONE));
    }


    public JComponent getObjectComponent() {
        if (checkBox == null) {
            checkBox = new JCheckBox();
            checkBox.addActionListener(new ActionListener() {


                public void actionPerformed(ActionEvent newE) {
                    updateModel();
                }

            });
            adjustSize(checkBox);
            synchronizeEditableState();
            updateView();
        }
        return checkBox;
    }


    @Override
    protected void synchronizeEditableState() {
        if (checkBox != null) {
            checkBox.setEnabled(isEditable() && isEnabled());
        }
    }


    @Override
    protected boolean isViewReady() {
        return (checkBox != null);
    }


    @Override
    protected Object getViewValue() {
        return (checkBox.isSelected()) ? Boolean.TRUE : Boolean.FALSE;
    }


    @Override
    protected void setViewValue(Object modelValue) {
        boolean val = (modelValue == null) ? false : ((Boolean) modelValue).booleanValue();
        checkBox.setSelected(val);
    }


}
