/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.cmp;


import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.sf.sfac.gui.editor.EditorContext;
import net.sf.sfac.lang.LanguageSupport;


/**
 * Editor used to edit a generic Object as field of another object. <br>
 * This Editor will show the embedded object as string in the generated form with a "browse" button allowing to open a popup editor
 * to edit the field.
 * 
 * @author Olivier Berlanger
 */
public class EmbededObjectEditor extends SimpleObjectEditor {

    private JPanel component;
    private JTextField objectTextField;
    private JButton browseButton;


    public JComponent getObjectComponent() {
        if (component == null) {
            objectTextField = new JTextField(25);
            registerFocusListener(objectTextField);
            // create browse button
            Dimension tfSize = objectTextField.getPreferredSize();
            browseButton = new JButton("...");
            browseButton.setPreferredSize(new Dimension(tfSize.height, tfSize.height));
            browseButton.addActionListener(new ActionListener() {

                public void actionPerformed(ActionEvent e) {
                    openSubEditor();
                }
            });
            browseButton.setToolTipText(LanguageSupport.getOptionalLocalizedString("VIEW_ITEM", "View Item"));
            browseButton.setEnabled(canViewItem());
            // Put them in a JPanel
            component = new JPanel(new BorderLayout());
            component.add(objectTextField, BorderLayout.CENTER);
            component.add(browseButton, BorderLayout.EAST);
            synchronizeEditableState();
            updateView();
        }
        return component;
    }


    @SuppressWarnings("unchecked")
    void openSubEditor() {
        EditorContext context = getEditorContext();
        if (context != null) {
            browseButton.setEnabled(false);
            Object result = context.editInContext(getModelValue(), (Class<Object>) getModelAccess().getModelClass(), this);
            if ((result != null) && isEditable() && isEnabled()) {
                setViewValue(result);
                updateModel();
            }
            browseButton.setEnabled(canViewItem());
        }
    }


    protected boolean canViewItem() {
        EditorContext edContext = getEditorContext();
        return (edContext != null) && edContext.canEditInContext(false, getModelAccess().getModelClass(), this);
    }


    @Override
    protected void synchronizeEditableState() {
        if (objectTextField != null) {
            objectTextField.setEditable(false);
            objectTextField.setEnabled(isEnabled());
        }
    }


    @Override
    protected boolean isViewReady() {
        return (objectTextField != null);
    }


    @Override
    protected Object getViewValue() {
        return null;
    }


    @Override
    public void updateModel() {
    }


    @Override
    public void setModelValue(Object newValue) {
    }


    @Override
    protected void setViewValue(Object modelValue) {
        String strValue = (modelValue == null) ? "" : modelValue.toString();
        objectTextField.setText(strValue);
    }


    @Override
    protected boolean valueHasChanged(Object oldValue, Object newValue) {
        return false;
    }

}
