/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.cmp;


import java.awt.Color;

import javax.swing.JComponent;
import javax.swing.JLabel;


/**
 * Object editor that just displays a text in a label (no edition).
 * 
 * @author Olivier Berlanger
 */
public class ReadOnlyObjectEditor extends SimpleObjectEditor {

    private String fixedText;
    private JLabel textLabel;


    public ReadOnlyObjectEditor() {
    }


    public ReadOnlyObjectEditor(String fixedTextToDispaly) {
        fixedText = fixedTextToDispaly;
    }


    public JComponent getObjectComponent() {
        if (textLabel == null) {
            textLabel = new JLabel();
            if (fixedText != null) {
                textLabel.setText(fixedText);
                textLabel.setForeground(Color.DARK_GRAY);
            }
            updateView();
        }
        return textLabel;
    }


    public boolean isModified() {
        return false;
    }


    @Override
    public boolean isEditable() {
        return false;
    }


    @Override
    public boolean isEnabled() {
        return false;
    }


    @Override
    public void updateModel() {
    }


    @Override
    protected boolean isViewReady() {
        return (textLabel != null);
    }


    @Override
    protected Object getViewValue() {
        return null;
    }


    @Override
    protected void setViewValue(Object modelValue) {
        if ((textLabel != null) && (fixedText == null)) {
            String text = (modelValue == null) ? "" : modelValue.toString();
            textLabel.setText(text);
        }
    }


    @Override
    protected void synchronizeEditableState() {
    }

}
