/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.cmp;


import java.awt.Dimension;

import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.sf.sfac.gui.editor.ModelAccess;
import net.sf.sfac.utils.Comparison;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;


/**
 * Editor used to edit a simple (leaf) object value (possibly immutable) as String, Integer, Date ... <br>
 * 
 * @author Olivier Berlanger
 */
public abstract class SimpleObjectEditor extends BaseObjectEditor {


    private static Log log = LogFactory.getLog(SimpleObjectEditor.class);
    private static final int DEFAULT_HEIGHT = new JTextField("A").getPreferredSize().height;


    private JComponent editorCmp;


    public JComponent getEditorComponent() {
        if (editorCmp == null) {
            JComponent theLabel = getLabelComponent();
            if (theLabel == null) {
                editorCmp = getObjectComponent();
            } else {
                editorCmp = new JPanel();
                editorCmp.add(theLabel);
                JComponent objectEditor = getObjectComponent();
                editorCmp.add(objectEditor);
            }
        }
        return editorCmp;
    }


    public static void adjustSize(JComponent cmp) {
        Dimension dim = cmp.getPreferredSize();
        if (dim.height != DEFAULT_HEIGHT) {
            if (log.isDebugEnabled()) log.debug("Ajust height from " + dim.height + " to " + DEFAULT_HEIGHT + " for " + cmp);
            Dimension newDim = new Dimension(dim.width, DEFAULT_HEIGHT);
            cmp.setPreferredSize(newDim);
            cmp.setMinimumSize(newDim);
        }
    }


    public void updateView() {
        try {
            // block all possible unwanted events during update view
            getEditorModificationSupport().setEnableEvents(false);
            updateLabelText();
            updateDescriptionText();
            if (isViewReady()) {
                setViewValue(getModelValue());
            }
        } finally {
            // allow events again
            getEditorModificationSupport().setEnableEvents(true);
        }
        checkViewVisibility();
    }


    @Override
    protected void checkViewVisibility() {
        ModelAccess visiAccess = getVisibilityAccess();

        if ((visiAccess != null) && isViewReady()) {
            Boolean visibilityBoolean = (Boolean) visiAccess.getModelValue(getEditedObject());
            if (visibilityBoolean == null) {
                log.warn("Visibility access " + visiAccess + " defined in " + this + " but returns null.");
            }
            boolean newVisibility = (visibilityBoolean == null) ? true : visibilityBoolean.booleanValue();
            boolean currentVisibility = getComponentVisibility();
            if (newVisibility != currentVisibility) {
                setComponentVisibility(newVisibility);
                getEditorModificationSupport().fireEditorVisibilityModified(currentVisibility);
            }
        }
    }


    public void updateModel() {
        if (isEditable() && isEnabled() && isViewReady()) {
            Object modelValue = getModelValue();
            Object viewValue = getViewValue();
            if (valueHasChanged(modelValue, viewValue)) {
                setModelValue(viewValue);
                getEditorModificationSupport().fireEditorValueModified(modelValue);
                updateView();
            }
        }
    }


    protected boolean valueHasChanged(Object oldValue, Object newValue) {
        return !Comparison.equals(oldValue, newValue);
    }


    @Override
    protected boolean getComponentVisibility() {
        if (editorCmp != null) return editorCmp.isVisible();
        return super.getComponentVisibility();
    }


    @Override
    protected void setComponentVisibility(boolean visible) {
        if (editorCmp != null) setComponentVisible(editorCmp, visible);
        else super.setComponentVisibility(visible);
    }


    protected abstract boolean isViewReady();


    protected abstract Object getViewValue();


    protected abstract void setViewValue(Object modelValue);


}
