/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.framework;


import javax.swing.JMenuBar;
import javax.swing.JToolBar;


/**
 * Actions support: this interface is used by the <code>ActionRepository</code> to notify listeners when the menuBar or the
 * Toolbar is created. So they have the opportunity to add custom components to the application bars like a comboBox (for the
 * toolbar) or a menu with dynamic content (for the menu bar).
 * 
 * @author Olivier Berlanger
 * @see ActionRepository
 */
public interface BarChangeListener {


    /**
     * Notification that the actions mnemonics will be assigned by the <code>ActionRepository</code>. Listeners can use this
     * hook to assign top-level mnemonics ...
     * 
     * @param repo
     *            the action repository which just created the menu bar.
     */
    public void beforeMnemonicAssignment(ActionRepository repo);


    /**
     * Notification that a toolbar has been created by the <code>ActionRepository</code>.
     * 
     * @param repo
     *            the action repository wich just created the menu bar.
     * @param toolbar
     *            the newly created the toolbar.
     */
    public void toolbarCreated(ActionRepository repo, JToolBar toolbar);


    /**
     * Notification that a menu bar has been created by the <code>ActionRepository</code>.
     * 
     * @param repo
     *            the action repository wich just created the menu bar.
     * @param menubar
     *            the newly created the menu bar.
     */
    public void menubarCreated(ActionRepository repo, JMenuBar menubar);


}
