/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.layout;


import java.awt.Component;
import java.awt.Dimension;
import java.awt.Insets;


/**
 * 
 * @author Olivier Berlanger
 */
class ComponentInfo {

    private static final Insets NULL_INSETS = new Insets(0, 0, 0, 0);

    private Component comp;
    private int width;
    private int height;
    private int filledWidth;
    private int filledHeight;

    private int anchor;
    private int fill;
    private Insets inset;


    ComponentInfo(Component cmp, MultiBorderConstraints constr) {
        comp = cmp;
        anchor = constr.anchor;
        fill = constr.fill;
        inset = (constr.insets == null) ? NULL_INSETS : (Insets) constr.insets.clone();
    }


    public int getWidth() {
        return width;
    }


    public int getHeight() {
        return height;
    }


    public int getAnchor() {
        return anchor;
    }


    public int getFill() {
        return fill;
    }


    public int getFilledWidth() {
        return filledWidth;
    }


    public void setFilledWidth(int newWidth) {
        filledWidth = newWidth;
    }


    public int getFilledHeight() {
        return filledHeight;
    }


    public void setFilledHeight(int newHeight) {
        filledHeight = newHeight;
    }


    public void calculateSize() {
        Dimension dim = comp.getPreferredSize();
        width = dim.width + inset.left + inset.right;
        height = dim.height + inset.top + inset.bottom;
    }


    /**
     * Lays out the component
     * 
     * @param startX
     *            the position of the left of the component.
     * @param startY
     *            the position of the top of the component.
     */
    public void layout(int startX, int startY) {
        int posX = startX + inset.left;
        int posY = startY + inset.top;
        int cmpWidth = filledWidth - (inset.left + inset.right);
        int cmpHeight = filledHeight - (inset.top + inset.bottom);
        comp.setBounds(posX, posY, cmpWidth, cmpHeight);
    }


    protected void setEnabled(boolean enabled) {
        comp.setEnabled(enabled);
    }


    protected void setVisible(boolean visible) {
        comp.setVisible(visible);
    }


    boolean checkComponent(Component cmp) {
        return cmp == comp;
    }

}
