/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.layout;


import java.awt.Insets;

import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JToggleButton;
import javax.swing.border.Border;


/**
 * ToggleExpandBorder is a ActionBorder with a little toggle button enabling to expand/collapse the content of this border.
 * 
 * @author Olivier Berlanger
 * @see ActionBorder
 * @see MultiBorderLayout
 * @see MultiBorderConstraints
 */
public class ToggleExpandBorder extends ActionBorder {

    private static final int ICON_NORMAL = 0;
    private static final int ICON_SELECTED = 1;
    // private static final int ICON_PRESSED = 2;
    // private static final int ICON_ROLL_OVER = 3;
    // private static final int ICON_DISABLED = 5;
    // private static final int ICON_ROLL_OVER_SELECTED = 4;
    // private static final int ICON_DISABLED_SELECTED = 6;
    private static final int NBR_ICONS = 2;
    private static final Icon[] DEFAULT_ICONS = new Icon[NBR_ICONS];


    /**
     * Creates an ExpandBorder using an EtchedBorder.
     */
    public ToggleExpandBorder() {
        init(createDefaultButton());
    }


    /**
     * Creates an ExpandBorder using an TitledBorder with the given title.
     * 
     * @param title
     *            the title of the titled border.
     */
    public ToggleExpandBorder(String title) {
        super(title);
        init(createDefaultButton());
    }


    /**
     * Creates an ExpandBorder using the given border.
     * 
     * @param thePaintedBorder
     *            the border painted by this MultiBorder
     */
    public ToggleExpandBorder(Border thePaintedBorder) {
        super(thePaintedBorder);
        init(createDefaultButton());
    }


    /**
     * Creates an ExpandBorder using an TitledBorder with the given title.
     * 
     * @param title
     *            the title of the titled border.
     */
    public ToggleExpandBorder(String title, JToggleButton button) {
        super(title);
        init(button);
    }


    /**
     * Creates an ExpandBorder using the given border.
     * 
     * @param thePaintedBorder
     *            the border painted by this MultiBorder
     */
    public ToggleExpandBorder(Border thePaintedBorder, JToggleButton button) {
        super(thePaintedBorder);
        init(button);
    }


    private JToggleButton createDefaultButton() {
        if (DEFAULT_ICONS[0] == null) {
            // load default icons
            for (int i = 0; i < NBR_ICONS; i++) {
                String iconName = "Expand" + i + ".gif";
                DEFAULT_ICONS[i] = new ImageIcon(getClass().getResource(iconName));
            }
        }
        JToggleButton button = new JToggleButton();
        button.setBorderPainted(false);
        button.setContentAreaFilled(false);
        button.setMargin(new Insets(0, 0, 0, 0));
        button.setOpaque(false);
        button.setIcon(DEFAULT_ICONS[ICON_NORMAL]);
        button.setSelectedIcon(DEFAULT_ICONS[ICON_SELECTED]);
        // button.setRolloverIcon(DEFAULT_ICONS[ICON_ROLL_OVER]) ;
        // button.setPressedIcon(DEFAULT_ICONS[ICON_PRESSED]) ;
        // button.setDisabledIcon(DEFAULT_ICONS[ICON_DISABLED]) ;
        // button.setDisabledSelectedIcon(DEFAULT_ICONS[ICON_DISABLED_SELECTED]) ;
        // button.setRolloverSelectedIcon(DEFAULT_ICONS[ICON_ROLL_OVER_SELECTED]) ;
        return button;
    }


    private void init(JToggleButton button) {
        setBorderAction(ActionBorder.ACTION_COLLAPSE);
        if (button != null) button.setSelected(true);
        setControlButton(button);
    }

}
