/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.utils;


import java.util.List;


/**
 * Common interface for objects managing selection of one or many objects. <br>
 * Typically for objects extending/containing a JTable, a JList or a JComboBox.
 * 
 * @author Olivier Berlanger
 */
public interface ObjectSelector {

    /** Get a unique ID identifying this selector. */
    public String getId();


    public Object getSelectedObject();


    public void clearSelection();


    public void selectDefaultItem();


    public boolean isMultiSelectionEnabled();


    public int getSelectedObjectCount();


    public List<?> getSelectedObjects();


    public boolean canSelectObjects(List<?> toSelect);


    public void selectObjects(List<?> toSelect);


    public void addObjectSelectionListener(ObjectSelectionListener lis);


    public void removeObjectSelectionListener(ObjectSelectionListener lis);

}
