/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.utils;


import javax.swing.plaf.ColorUIResource;
import javax.swing.plaf.FontUIResource;
import javax.swing.plaf.metal.DefaultMetalTheme;


/**
 * A theme for the Metal look-and-feel. <br>
 * This theme defines a windows-like thin font (used by example in menus) instead of the default metal bold font and blueish colors.
 * 
 * @author Olivier Berlanger
 */
public class ThinMetalTheme extends DefaultMetalTheme {

    // // gray set
    // private final ColorUIResource primary1 = new ColorUIResource(0, 0, 0);
    // private final ColorUIResource primary2 = new ColorUIResource(153, 153, 153);
    // private final ColorUIResource primary3 = new ColorUIResource(204, 204, 204);

    // // green set
    // private final ColorUIResource primary1 = new ColorUIResource(102, 153, 102);
    // private final ColorUIResource primary2 = new ColorUIResource(153, 204, 153);
    // private final ColorUIResource primary3 = new ColorUIResource(204, 255, 204);

    // blue set
    private final ColorUIResource primary1 = new ColorUIResource(0, 58, 178);
    private final ColorUIResource primary2 = new ColorUIResource(98, 150, 215);
    private final ColorUIResource primary3 = new ColorUIResource(150, 200, 255);


    /**
     * Create a <code>ThinMetalTheme</code>.
     */
    public ThinMetalTheme() {
    }


    /**
     * Get the name of this Metal theme.
     * 
     * @return The name of this theme.
     */
    @Override
    public String getName() {
        return "Thin";
    }


    /**
     * Override the primary1 color with a blue one.
     * 
     * @return the primary1 color.
     */
    @Override
    protected ColorUIResource getPrimary1() {
        return primary1;
    }


    /**
     * Override the primary2 color with a blue one.
     * 
     * @return the primary2 color.
     */
    @Override
    protected ColorUIResource getPrimary2() {
        return primary2;
    }


    /**
     * Override the primary3 color with a blue one.
     * 
     * @return the primary3 color.
     */
    @Override
    protected ColorUIResource getPrimary3() {
        return primary3;
    }


    /**
     * Use plain font for control text (instead of bold).
     * 
     * @return Plain font for control text.
     */
    @Override
    public FontUIResource getControlTextFont() {
        return getSystemTextFont();
    }


    /**
     * Use plain font for menu text (instead of bold).
     * 
     * @return Plain font for menu text.
     */
    @Override
    public FontUIResource getMenuTextFont() {
        return getSystemTextFont();
    }

}
